# Copyright (c) 2000-2008, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

Name:           jarjar
Version:        1.4
Release:        %mkrel 17
Group:          Development/Java
Summary:        Jar Jar Links
License:        ASL 2.0
URL:            http://code.google.com/p/jarjar/
Source0:        http://jarjar.googlecode.com/files/jarjar-src-1.4.zip
Source1:        jarjar.pom
Source2:        jarjar-util.pom
Patch0:         fix-maven-plugin.patch
Patch1:         do-not-embed-asm.patch

BuildRequires:  ant
BuildRequires:  ant-junit
BuildRequires:  objectweb-asm
BuildRequires:  javapackages-local
BuildRequires:  maven
Requires:       objectweb-asm

BuildArch:      noarch

%description
Jar Jar Links is a utility that makes it easy to repackage Java 
libraries and embed them into your own distribution. This is 
useful for two reasons:
You can easily ship a single jar file with no external dependencies. 
You can avoid problems where your library depends on a specific 
version of a library, which may conflict with the dependencies of 
another library.

%package maven-plugin
Summary:        Maven plugin for %{name}
Requires:       maven
Requires:       %{name} = %{version}-%{release}

%description maven-plugin
%{summary}.

%package javadoc
Summary:        Javadoc for %{name}

%description javadoc
%{summary}.

%prep
%setup -q -n %{name}-%{version}
%patch0
%patch1

# remove all binary libs
rm -f lib/*.jar

%mvn_package :jarjar-plugin %{name}-maven-plugin

# create ant config
echo "jarjar/jarjar objectweb-asm/asm objectweb-asm/asm-commons" > jarjar.ant

%build
pushd lib
ln -sf $(build-classpath objectweb-asm/asm) asm-4.0.jar
ln -sf $(build-classpath objectweb-asm/asm-commons) asm-commons-4.0.jar
ln -sf $(build-classpath maven/maven-plugin-api) maven-plugin-api.jar
popd
export CLASSPATH=$(build-classpath ant)
ant jar jar-util javadoc mojo test

sed -i -e s/@VERSION@/%{version}/g maven/pom.xml

# request maven artifact installation
%mvn_artifact %{SOURCE1} dist/jarjar-%{version}.jar
%mvn_artifact %{SOURCE2} dist/jarjar-util-%{version}.jar
%mvn_artifact maven/pom.xml dist/jarjar-plugin-%{version}.jar
%mvn_alias tonic:jarjar jarjar:jarjar com.tonicsystems:jarjar com.googlecode.jarjar:jarjar org.gradle.jarjar:jarjar
%mvn_alias tonic:jarjar-util jarjar:jarjar-util com.tonicsystems:jarjar-util
%mvn_alias com.tonicsystems.jarjar:jarjar-plugin jarjar:jarjar-plugin tonic:jarjar-plugin com.tonicsystems:jarjar-plugin

%install
%mvn_install -J dist/javadoc

%jpackage_script com.tonicsystems.jarjar.Main "" "" jarjar/jarjar:objectweb-asm/asm:objectweb-asm/asm-commons %{name} true

# install ant config
install -m 644 -D jarjar.ant %{buildroot}%{_sysconfdir}/ant.d/jarjar

%files -f .mfiles
%doc COPYING
%{_bindir}/%{name}
%{_sysconfdir}/ant.d/jarjar
%dir %{_javadir}/%{name}

%files maven-plugin -f .mfiles-%{name}-maven-plugin
%doc COPYING

%files javadoc -f .mfiles-javadoc
%doc COPYING



%changelog
* Wed Mar 02 2016 neoclust <neoclust> 1.4-17.mga6
+ Revision: 981884
- Second rebuild of the java stack

* Tue Feb 23 2016 neoclust <neoclust> 1.4-16.mga6
+ Revision: 976498
- First rebuild of the java stack
- sync package jarjar with fedora

  + umeabot <umeabot>
    - Mageia 6 Mass Rebuild

* Sat Dec 27 2014 daviddavid <daviddavid> 1.4-5.mga5
+ Revision: 806551
- Sync with fc21

  + umeabot <umeabot>
    - Second Mageia 5 Mass Rebuild
    - Mageia 5 Mass Rebuild

* Tue Oct 22 2013 umeabot <umeabot> 1.4-2.mga4
+ Revision: 541745
- Mageia 4 Mass Rebuild

* Sun Oct 13 2013 dmorgan <dmorgan> 1.4-1.mga4
+ Revision: 496399
- New version

* Sat Jan 12 2013 umeabot <umeabot> 0:1.0-6.mga3
+ Revision: 354751
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Sep 09 2012 dmorgan <dmorgan> 0:1.0-5.mga3
+ Revision: 290717
- Do not require maven2.

* Thu Feb 03 2011 dmorgan <dmorgan> 0:1.0-4.mga1
+ Revision: 46535
- Add back epoch

* Thu Feb 03 2011 pterjan <pterjan> 1.0-3.mga1
+ Revision: 46531
- Increase release to get higher than mandriva

* Thu Feb 03 2011 dmorgan <dmorgan> 1.0-1.mga1
+ Revision: 46521
- Fix typo
- Remove fedora macros
- Fix requires
- Fix release
- Update to 1.0 ( from fedora )
- Build with maven
- Try to remove maven on export too
- Bootstrap maven deps
- imported package jarjar


* Sat Dec 04 2010 Oden Eriksson <oeriksson@mandriva.com> 0:1.0-2.rc7.4mdv2011.0
+ Revision: 609148
- rebuild
- rebuilt for 2010.1

* Wed Sep 02 2009 Christophe Fergeau <cfergeau@mandriva.com> 0:1.0-2.rc7.2mdv2010.0
+ Revision: 425450
- rebuild

* Wed Aug 06 2008 Thierry Vignaud <tv@mandriva.org> 0:1.0-2.rc7.1mdv2009.0
+ Revision: 264722
- rebuild early 2009.0 package (before pixel changes)

* Wed Apr 16 2008 Alexander Kurtakov <akurtakov@mandriva.org> 0:1.0-0.rc7.1mdv2009.0
+ Revision: 194605
- require asm3 instead of asm2, drop gnu.regexp require
- new version

  + Thierry Vignaud <tv@mandriva.org>
    - fix no-buildroot-tag
    - kill re-definition of %%buildroot on Pixel's request

* Sun Dec 16 2007 Anssi Hannula <anssi@mandriva.org> 0:0.9-1.0.5mdv2008.1
+ Revision: 120924
- buildrequire java-rpmbuild, i.e. build with icedtea on x86(_64)

* Sat Sep 15 2007 Anssi Hannula <anssi@mandriva.org> 0:0.9-1.0.4mdv2008.0
+ Revision: 87422
- rebuild to filter out autorequires of GCJ AOT objects
- remove unnecessary Requires(post) on java-gcj-compat

* Sat Sep 01 2007 David Walluck <walluck@mandriva.org> 0:0.9-1.0.3mdv2008.0
+ Revision: 77265
- fix typo
- bump release
- 0.9


* Sat Dec 16 2006 David Walluck <walluck@mandriva.org> 0.6-2.1mdv2007.0
+ Revision: 97988
- use gcjdb macros
- Import jarjar

* Fri Dec 15 2006 David Walluck <walluck@mandriva.org> 0:0.6-2.1mdv2007.1
- release

* Thu Jan 05 2006 Fernando Nasser <fnasser@redhat.com> - 0:0.6-2jpp
- First JPP 1.7 build

* Thu Oct 20 2005 Ralph Apel <r.apel@r-apel.de> - 0:0.6-1jpp
- First JPackage build

